cumulusci.core.tests package
============================

Submodules
----------


.. automodule:: cumulusci.core.tests.BarTestPage
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.core.tests.FooTestPage
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.core.tests.test_config
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.core.tests.test_config_expensive
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.core.tests.test_exceptions
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.core.tests.test_flowrunner
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.core.tests.test_github
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.core.tests.test_keychain
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.core.tests.test_pageobjects
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.core.tests.test_salesforce
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.core.tests.test_salesforce_locators
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.core.tests.test_source
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.core.tests.test_tasks
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.core.tests.test_utils
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.core.tests.utils
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.core.tests
   :members:
   :undoc-members:
   :show-inheritance:
